ApiDataListWidget | django_cradmin API Document

    import ApiDataListWidget from 'django_cradmin/scripts/django_cradmin/widgets/ApiDataListWidget.js'

public class | source

# ApiDataListWidget

#### Extends:

ievv_jsbase/widget/AbstractWidget~AbstractWidget → AbstractDataListWidget → ApiDataListWidget

## Constructor Summary

Public Constructor
public | constructor(element: *, widgetInstanceId: *) |

## Member Summary

Public Members
public get | classPath: string |

## Method Summary

Public Methods
public | addFiltersToQueryString(filtersMap: *, queryString: *) |
public | requestDataList(options: *): * |
public | requestItemData(key: *): * |

## Inherited Summary

From class AbstractDataListWidget
public | logger: * |
public | signalHandlersInitialized: boolean |
public | state: * |
public | afterInitializeAllWidgets() |
public | destroy() |
public | getDefaultConfig(): * |
public | makeRequestDataListOptions(overrideOptions: {}): * |
public | requestDataList() |
public | requestItemData(key: *) |
public | setState(stateChange: *, initial: boolean) |
public | useAfterInitializeAllWidgets(): boolean |

## Public Constructors

### public constructor(element: *, widgetInstanceId: *) source

#### Override:

AbstractDataListWidget#constructor

#### Params:

Name | Type | Attribute | Description
element | * |  |
widgetInstanceId | * |  |

## Public Members

### public get classPath: string source

## Public Methods

### public addFiltersToQueryString(filtersMap: *, queryString: *) source

#### Params:

Name | Type | Attribute | Description
filtersMap | * |  |
queryString | * |  |

### public requestDataList(options: *): * source

#### Override:

AbstractDataListWidget#requestDataList

#### Params:

Name | Type | Attribute | Description
options | * |  |

#### Return:

*

### public requestItemData(key: *): * source

#### Override:

AbstractDataListWidget#requestItemData

#### Params:

Name | Type | Attribute | Description
key | * |  |

#### Return:

*